@@ -85,9 +85,7 @@ impl<const LIMBS: usize> PartialEq for UInt<LIMBS> {
 #[cfg(test)]
 mod tests {
     use crate::U128;
-    use subtle::{
-        Choice, ConditionallySelectable, ConstantTimeEq, ConstantTimeGreater, ConstantTimeLess,
-    };
+    use subtle::{ConstantTimeEq, ConstantTimeGreater, ConstantTimeLess};
 
     #[test]
     fn is_zero() {
@@ -103,15 +101,6 @@ mod tests {
         assert!(bool::from(U128::MAX.is_odd()));
     }
 
-    #[test]
-    fn conditional_select() {
-        let a = U128::ZERO;
-        let b = U128::MAX;
-
-        assert_eq!(U128::conditional_select(&a, &b, Choice::from(0)), a);
-        assert_eq!(U128::conditional_select(&a, &b, Choice::from(1)), b);
-    }
-
     #[test]
     fn ct_eq() {
         let a = U128::ZERO;
